@@ -19,6 +19,8 @@
   digits<-paste("c(",paste(digits,collapse=","),")")  
   digits.ratio<-paste("c(",paste(digits.ratio,collapse=","),")")  
   obj.i<-attr(x,"x")[[1]][i]
+  if (inherits(x, "descrTable"))
+    class(x) <- class(x)[class(x)!="descrTable"]
   ans<-eval(parse(text=paste("update(x,x=obj.i,hide=",hide,",digits=",digits,")",sep="")))
   class(ans)<-class.orig
   ans
